# Automagic REST

Automagic REST automatically builds a full Django app as a Django REST Framework read-only environment for a set of tables in a PostgreSQL database.

This is very much in heavy development, being extracted from a production system and genericized for open source release.
